@@ -46,14 +46,18 @@ gth_browser_activate_remove_from_catalog (GSimpleAction	 *action,
 	GthBrowser *browser = GTH_BROWSER (user_data);
 	GList *items;
 	GList *file_data_list;
+	GList *file_list;
 
 	items = gth_file_selection_get_selected (GTH_FILE_SELECTION (gth_browser_get_file_list_view (browser)));
 	file_data_list = gth_file_list_get_files (GTH_FILE_LIST (gth_browser_get_file_list (browser)), items);
+	file_list = gth_file_data_list_to_file_list (file_data_list);
 
 	gth_catalog_manager_remove_files (GTK_WINDOW (browser),
 					  gth_browser_get_location_data (browser),
-					  file_data_list);
+					  file_list,
+					  TRUE);
 
+	_g_object_list_unref (file_list);
 	_g_object_list_unref (file_data_list);
 	_gtk_tree_path_list_free (items);
 }
