@@ -594,13 +594,10 @@ update_play_button (GthMediaViewerPage *self,
 	}
 	else if (self->priv->playing && (new_state != GST_STATE_PLAYING)) {
 		GtkWidget *play_button = GET_WIDGET ("play_button_image");
-		gboolean   rtl;
-
-		rtl = gtk_widget_get_direction (play_button) == GTK_TEXT_DIR_RTL;
 
 		set_playing_state (self, FALSE);
 		gtk_image_set_from_icon_name (GTK_IMAGE (play_button),
-					      rtl ? "media-playback-start-rtl-symbolic" : "media-playback-start-symbolic",
+					      "media-playback-start-symbolic",
 					      GTK_ICON_SIZE_LARGE_TOOLBAR);
 		gtk_widget_set_tooltip_text (GET_WIDGET ("play_button_image"), _("Play"));
 
@@ -621,7 +618,6 @@ gth_media_viewer_page_real_activate (GthViewerPage *base,
 				     GthBrowser    *browser)
 {
 	GthMediaViewerPage *self;
-	gboolean            rtl;
 
 	if (! gstreamer_init ())
 		return;
@@ -641,8 +637,6 @@ gth_media_viewer_page_real_activate (GthViewerPage *base,
 							   "win.video-screenshot",
 							   NULL);
 
-	rtl = gtk_widget_get_default_direction () == GTK_TEXT_DIR_RTL;
-
 	/* video area */
 
 	self->priv->area = gtk_drawing_area_new ();
@@ -706,10 +700,10 @@ gth_media_viewer_page_real_activate (GthViewerPage *base,
 	gtk_widget_set_valign (self->priv->mediabar, GTK_ALIGN_END);
 
 	gtk_image_set_from_icon_name (GTK_IMAGE (GET_WIDGET ("play_slower_image")),
-				      rtl ? "media-seek-backward-rtl-symbolic" : "media-seek-backward-symbolic",
+				      "media-seek-backward-symbolic",
 				      GTK_ICON_SIZE_MENU);
 	gtk_image_set_from_icon_name (GTK_IMAGE (GET_WIDGET ("play_faster_image")),
-				      rtl ? "media-seek-forward-rtl-symbolic" : "media-seek-forward-symbolic",
+				      "media-seek-forward-symbolic",
 				      GTK_ICON_SIZE_MENU);
 
 	g_signal_connect (GET_WIDGET ("volume_adjustment"),
