@@ -30,13 +30,14 @@
 
 #define UPDATE_QUALITY_DELAY 200
 #define UPDATE_VISIBILITY_DELAY 100
-#define N_HEADER_BAR_BUTTONS 5
+#define N_HEADER_BAR_BUTTONS 6
 #define HIDE_OVERVIEW_TIMEOUT 2 /* in seconds */
 #define OVERLAY_MARGIN 10
-#define APPLY_ICC_PROFILE_BUTTON 4
+#define ZOOM_BUTTON 2
+#define APPLY_ICC_PROFILE_BUTTON 3
+#define TOGGLE_ANIMATION_BUTTON 4
+#define STEP_ANIMATION_BUTTON 5
 #undef ALWAYS_LOAD_ORIGINAL_SIZE
-#define N_FORWARD_PRELOADERS 2
-#define N_BACKWARD_PRELOADERS 2
 
 
 static void gth_viewer_page_interface_init (GthViewerPageInterface *iface);
@@ -54,6 +55,7 @@ static const GActionEntry actions[] = {
 	{ "image-zoom-out", gth_browser_activate_image_zoom_out },
 	{ "image-zoom-100", gth_browser_activate_image_zoom_100 },
 	{ "image-zoom-fit", gth_browser_activate_image_zoom_fit },
+	{ "image-zoom-fit-if-larger", gth_browser_activate_image_zoom_fit_if_larger },
 	{ "image-zoom-fit-width", gth_browser_activate_image_zoom_fit_width },
 	{ "image-zoom-fit-height", gth_browser_activate_image_zoom_fit_height },
 	{ "image-undo", gth_browser_activate_image_undo },
@@ -61,6 +63,9 @@ static const GActionEntry actions[] = {
 	{ "copy-image", gth_browser_activate_copy_image },
 	{ "paste-image", gth_browser_activate_paste_image },
 	{ "apply-icc-profile", toggle_action_activated, NULL, "true", gth_browser_activate_apply_icc_profile },
+	{ "toggle-animation", toggle_action_activated, NULL, "true", gth_browser_activate_toggle_animation },
+	{ "step-animation", gth_browser_activate_step_animation },
+	{ "image-zoom", gth_browser_activate_image_zoom, "s", "''", NULL },
 };
 
 
@@ -98,12 +103,11 @@ struct _GthImageViewerPagePrivate {
 	guint              update_quality_id;
 	guint		   update_visibility_id;
 	GtkWidget         *buttons[N_HEADER_BAR_BUTTONS];
+	GtkBuilder        *builder;
 	gboolean           pointer_on_viewer;
 	gboolean           pointer_on_overview;
 	guint              hide_overview_id;
 	gboolean           apply_icc_profile;
-	GthFileData       *next_file_data[N_FORWARD_PRELOADERS];
-	GthFileData       *prev_file_data[N_BACKWARD_PRELOADERS];
 };
 
 
@@ -195,44 +199,6 @@ _gth_image_preloader_get_requested_size_for_current_image (GthImageViewerPage *s
 }
 
 
-static void
-_gth_image_viewer_page_load_with_preloader (GthImageViewerPage  *self,
-					    GthFileData         *file_data,
-					    int                  requested_size,
-					    GCancellable        *cancellable,
-					    GAsyncReadyCallback  callback,
-					    gpointer		 user_data)
-{
-	if (self->priv->apply_icc_profile)
-		gth_image_preloader_set_out_profile (self->priv->preloader, gth_browser_get_screen_profile (self->priv->browser));
-	else
-		gth_image_preloader_set_out_profile (self->priv->preloader, NULL);
-
-	g_object_ref (self);
-	gth_image_preloader_load (self->priv->preloader,
-				  file_data,
-				  requested_size,
-				  cancellable,
-				  callback,
-				  user_data,
-				  N_FORWARD_PRELOADERS + N_BACKWARD_PRELOADERS,
-				  self->priv->next_file_data[0],
-				  self->priv->next_file_data[1],
-				  self->priv->prev_file_data[0],
-				  self->priv->prev_file_data[1]);
-}
-
-
-static gboolean
-_gth_image_viewer_page_load_with_preloader_finish (GthImageViewerPage  *self)
-{
-	gboolean active = self->priv->active;
-	g_object_unref (self);
-
-	return active;
-}
-
-
 static void
 different_quality_ready_cb (GObject		*source_object,
 			    GAsyncResult	*result,
@@ -250,9 +216,6 @@ different_quality_ready_cb (GObject		*source_object,
 	int                 w1, h1, w2, h2;
 	gboolean            got_better_quality;
 
-	if (! _gth_image_viewer_page_load_with_preloader_finish (self))
-		return;
-
 	if (! gth_image_preloader_load_finish (GTH_IMAGE_PRELOADER (source_object),
 					       result,
 					       &requested,
@@ -310,29 +273,30 @@ _g_mime_type_can_load_different_quality (const char *mime_type)
 	static const char *supported[] = {
 		"image/jpeg",
 		"image/x-portable-pixmap"
-
-		/* RAW formats: to keep in sync with raw_mime_types in extensions/raw_files/main.c */
-
-		"image/x-adobe-dng",
-		"image/x-canon-cr2",
-		"image/x-canon-crw",
-		"image/x-epson-erf",
-		"image/x-minolta-mrw",
-		"image/x-nikon-nef",
-		"image/x-olympus-orf",
-		"image/x-pentax-pef",
-		"image/x-sony-arw"
 	};
-	int i;
 
+	int i;
 	for (i = 0; i < G_N_ELEMENTS (supported); i++)
 		if (g_strcmp0 (mime_type, supported[i]) == 0)
 			return TRUE;
 
+	if (_g_mime_type_is_raw (mime_type))
+		return TRUE;
+
 	return FALSE;
 }
 
 
+static void
+_gth_image_preloader_init_preloader (GthImageViewerPage *self)
+{
+	if (self->priv->apply_icc_profile)
+		gth_image_preloader_set_out_profile (self->priv->preloader, gth_browser_get_screen_profile (self->priv->browser));
+	else
+		gth_image_preloader_set_out_profile (self->priv->preloader, NULL);
+}
+
+
 static gboolean
 update_quality_cb (gpointer user_data)
 {
@@ -343,24 +307,21 @@ update_quality_cb (gpointer user_data)
 		self->priv->update_quality_id = 0;
 	}
 
-	if (! self->priv->active)
-		return FALSE;
-
-	if (self->priv->viewer == NULL)
-		return FALSE;
-
 	if (self->priv->loading_image)
 		return FALSE;
 
 	if (! self->priv->image_changed && ! _g_mime_type_can_load_different_quality (gth_file_data_get_mime_type (self->priv->file_data)))
 		return FALSE;
 
-	_gth_image_viewer_page_load_with_preloader (self,
-						    self->priv->image_changed ? GTH_MODIFIED_IMAGE : self->priv->file_data,
-						    _gth_image_preloader_get_requested_size_for_current_image (self),
-						    NULL,
-						    different_quality_ready_cb,
-						    self);
+	_gth_image_preloader_init_preloader (self);
+	gth_image_preloader_load (self->priv->preloader,
+				  self->priv->image_changed ? GTH_MODIFIED_IMAGE : self->priv->file_data,
+				  _gth_image_preloader_get_requested_size_for_current_image (self),
+				  NULL,
+				  different_quality_ready_cb,
+				  self,
+				  GTH_NO_PRELOADERS,
+				  NULL);
 
 	return FALSE;
 }
@@ -412,7 +373,6 @@ update_overview_visibility_now (gpointer user_data)
 {
 	GthImageViewerPage *self;
 	gboolean            overview_visible;
-	gboolean            revealed;
 
 	self = GTH_IMAGE_VIEWER_PAGE (user_data);
 
@@ -451,17 +411,109 @@ update_overview_visibility (GthImageViewerPage *self)
 }
 
 
+#define MIN_ZOOM_LEVEL 0.3
+#define MAX_ZOOM_LEVEL 3.0
+
+
+static void
+zoom_scale_value_changed_cb (GtkScale *scale,
+			     gdouble   value,
+			     gpointer  user_data)
+{
+	GthImageViewerPage *self = user_data;
+	double              x, zoom;
+
+	x = gtk_range_get_value (GTK_RANGE (scale));
+	zoom = MIN_ZOOM_LEVEL + (x / 100.0 * (MAX_ZOOM_LEVEL - MIN_ZOOM_LEVEL));
+	gth_image_viewer_set_zoom (GTH_IMAGE_VIEWER (self->priv->viewer), zoom);
+}
+
+
+static void
+zoom_button_toggled_cb (GtkToggleButton *togglebutton,
+	                gpointer         user_data)
+{
+	GthImageViewerPage *self = user_data;
+
+	if (! gtk_toggle_button_get_active (togglebutton))
+		return;
+
+	gth_browser_keep_mouse_visible (self->priv->browser, TRUE);
+}
+
+
+static void
+zoom_popover_closed_cb (GtkPopover *popover,
+			gpointer    user_data)
+{
+	GthImageViewerPage *self = user_data;
+
+	gth_browser_keep_mouse_visible (self->priv->browser, FALSE);
+	call_when_idle ((DataFunc) gth_viewer_page_focus, self);
+}
+
+
+#define ZOOM_EQUAL(a,b) (fabs (a - b) < 1e-3)
+
+
 static void
 update_zoom_info (GthImageViewerPage *self)
 {
 	double  zoom;
 	char   *text;
+	double  x;
+
+	/* status bar */
 
 	zoom = gth_image_viewer_get_zoom (GTH_IMAGE_VIEWER (self->priv->viewer));
 	text = g_strdup_printf ("  %d%%  ", (int) (zoom * 100));
 	gth_statusbar_set_secondary_text (GTH_STATUSBAR (gth_browser_get_statusbar (self->priv->browser)), text);
-
 	g_free (text);
+
+	/* zoom menu */
+
+	gboolean    zoom_enabled;
+	GthFit      fit_mode;
+	GAction    *action;
+	const char *state;
+
+	zoom_enabled = gth_image_viewer_get_zoom_enabled (GTH_IMAGE_VIEWER (self->priv->viewer));
+	fit_mode = gth_image_viewer_get_fit_mode (GTH_IMAGE_VIEWER (self->priv->viewer));
+
+	gth_window_enable_action (GTH_WINDOW (self->priv->browser), "image-zoom", zoom_enabled);
+
+	state = "";
+	if (fit_mode == GTH_FIT_SIZE)
+		state = "fit";
+	else if (fit_mode == GTH_FIT_WIDTH)
+		state = "fit-width";
+	else if (fit_mode == GTH_FIT_HEIGHT)
+		state = "fit-height";
+	else if (fit_mode == GTH_FIT_SIZE_IF_LARGER)
+		state = "automatic";
+	else if (ZOOM_EQUAL (zoom, 0.5))
+		state = "50";
+	else if (ZOOM_EQUAL (zoom, 1.0))
+		state = "100";
+	else if (ZOOM_EQUAL (zoom, 2.0))
+		state = "200";
+	else if (ZOOM_EQUAL (zoom, 3.0))
+		state = "300";
+
+	action = g_action_map_lookup_action (G_ACTION_MAP (self->priv->browser), "image-zoom");
+	g_simple_action_set_state (G_SIMPLE_ACTION (action), g_variant_new_string (state));
+
+	gth_window_enable_action (GTH_WINDOW (self->priv->browser), "image-zoom-100", ! ZOOM_EQUAL (zoom, 1.0));
+	gth_window_enable_action (GTH_WINDOW (self->priv->browser), "image-zoom-fit-if-larger", fit_mode != GTH_FIT_SIZE_IF_LARGER);
+
+	/* zoom menu scale */
+
+	GtkWidget *scale = _gtk_builder_get_widget (self->priv->builder, "zoom_level_scale");
+
+	g_signal_handlers_block_by_data (scale, self);
+	x = (zoom - MIN_ZOOM_LEVEL) / (MAX_ZOOM_LEVEL - MIN_ZOOM_LEVEL) * 100.0;
+	gtk_range_set_value (GTK_RANGE (scale), CLAMP (x, 0, 100));
+	g_signal_handlers_unblock_by_data (scale, self);
 }
 
 
@@ -469,7 +521,6 @@ static void
 viewer_zoom_changed_cb (GtkWidget          *widget,
 			GthImageViewerPage *self)
 {
-	gth_viewer_page_update_sensitivity (GTH_VIEWER_PAGE (self));
 	update_image_quality_if_required (self);
 	self->priv->pointer_on_viewer = TRUE;
 	update_overview_visibility (self);
@@ -585,7 +636,7 @@ viewer_realize_cb (GtkWidget *widget,
 	GthImageViewerPage *self = user_data;
 	GtkClipboard       *clipboard;
 
-	clipboard = gtk_widget_get_clipboard (widget, GDK_SELECTION_CLIPBOARD);
+	clipboard = gtk_widget_get_clipboard (self->priv->viewer, GDK_SELECTION_CLIPBOARD);
 	g_signal_connect (clipboard,
 	                  "owner_change",
 	                  G_CALLBACK (clipboard_owner_change_cb),
@@ -600,7 +651,7 @@ viewer_unrealize_cb (GtkWidget *widget,
 	GthImageViewerPage *self = user_data;
 	GtkClipboard       *clipboard;
 
-	clipboard = gtk_widget_get_clipboard (widget, GDK_SELECTION_CLIPBOARD);
+	clipboard = gtk_widget_get_clipboard (self->priv->viewer, GDK_SELECTION_CLIPBOARD);
 	g_signal_handlers_disconnect_by_func (clipboard,
 	                                      G_CALLBACK (clipboard_owner_change_cb),
 	                                      self);
@@ -624,6 +675,8 @@ image_navigator_get_child_position_cb	(GtkOverlay   *overlay,
 	if (widget == self->priv->overview_revealer) {
 		allocation->x = main_alloc.width - allocation->width - OVERLAY_MARGIN;
 		allocation->y = OVERLAY_MARGIN;
+		if (gth_browser_get_is_fullscreen (self->priv->browser))
+			allocation->y += gtk_widget_get_allocated_height (gth_browser_get_fullscreen_headerbar (self->priv->browser));
 		allocation_filled = TRUE;
 	}
 
@@ -673,9 +726,6 @@ pref_zoom_quality_changed (GSettings *settings,
 {
 	GthImageViewerPage *self = user_data;
 
-	if (! self->priv->active || (self->priv->viewer == NULL))
-		return;
-
 	gth_image_viewer_set_zoom_quality (GTH_IMAGE_VIEWER (self->priv->viewer),
 					   g_settings_get_enum (self->priv->settings, PREF_IMAGE_VIEWER_ZOOM_QUALITY));
 	gtk_widget_queue_draw (self->priv->viewer);
@@ -689,9 +739,6 @@ pref_zoom_change_changed (GSettings *settings,
 {
 	GthImageViewerPage *self = user_data;
 
-	if (! self->priv->active || (self->priv->viewer == NULL))
-		return;
-
 	gth_image_viewer_set_zoom_change (GTH_IMAGE_VIEWER (self->priv->viewer),
 					  g_settings_get_enum (self->priv->settings, PREF_IMAGE_VIEWER_ZOOM_CHANGE));
 	gtk_widget_queue_draw (self->priv->viewer);
@@ -705,9 +752,6 @@ pref_reset_scrollbars_changed (GSettings *settings,
 {
 	GthImageViewerPage *self = user_data;
 
-	if (! self->priv->active || (self->priv->viewer == NULL))
-		return;
-
 	gth_image_viewer_set_reset_scrollbars (GTH_IMAGE_VIEWER (self->priv->viewer),
 					       g_settings_get_boolean (self->priv->settings, PREF_IMAGE_VIEWER_RESET_SCROLLBARS));
 }
@@ -874,48 +918,70 @@ gth_image_viewer_page_real_activate (GthViewerPage *base,
 					 actions,
 					 G_N_ELEMENTS (actions),
 					 browser);
+
 	self->priv->buttons[0] =
 			gth_browser_add_header_bar_button (browser,
-							   GTH_BROWSER_HEADER_SECTION_VIEWER_VIEW,
+							   GTH_BROWSER_HEADER_SECTION_VIEWER_ZOOM,
 							   "view-zoom-original-symbolic",
 							   _("Set to actual size"),
 							   "win.image-zoom-100",
 							   NULL);
 	self->priv->buttons[1] =
 			gth_browser_add_header_bar_button (browser,
-							   GTH_BROWSER_HEADER_SECTION_VIEWER_VIEW,
+							   GTH_BROWSER_HEADER_SECTION_VIEWER_ZOOM,
 							   "view-zoom-fit-symbolic",
-							   _("Fit to window"),
-							   "win.image-zoom-fit",
-							   NULL);
-	self->priv->buttons[2] =
-			gth_browser_add_header_bar_button (browser,
-							   GTH_BROWSER_HEADER_SECTION_VIEWER_VIEW,
-							   "view-zoom-fit-width-symbolic",
-							   _("Fit to width"),
-							   "win.image-zoom-fit-width",
-							   NULL);
-	self->priv->buttons[3] =
-			gth_browser_add_header_bar_button (browser,
-							   GTH_BROWSER_HEADER_SECTION_VIEWER_VIEW,
-							   "view-zoom-fit-height-symbolic",
-							   _("Fit to height"),
-							   "win.image-zoom-fit-height",
+							   _("Fit to window if larger"),
+							   "win.image-zoom-fit-if-larger",
 							   NULL);
+
+	self->priv->builder = gtk_builder_new_from_resource ("/org/gnome/gThumb/image_viewer/data/ui/toolbar-zoom-menu.ui");
+	self->priv->buttons[ZOOM_BUTTON] =
+			gth_browser_add_header_bar_menu_button (browser,
+								GTH_BROWSER_HEADER_SECTION_VIEWER_ZOOM,
+								"view-zoom-in-symbolic",
+								NULL,
+								_gtk_builder_get_widget (self->priv->builder, "zoom_popover"));
+	g_signal_connect (_gtk_builder_get_widget (self->priv->builder, "zoom_level_scale"),
+			  "value-changed",
+			  G_CALLBACK (zoom_scale_value_changed_cb),
+			  self);
+	g_signal_connect (self->priv->buttons[ZOOM_BUTTON],
+			  "toggled",
+			  G_CALLBACK (zoom_button_toggled_cb),
+			  self);
+	g_signal_connect (_gtk_builder_get_widget (self->priv->builder, "zoom_popover"),
+			  "closed",
+			  G_CALLBACK (zoom_popover_closed_cb),
+			  self);
+
 	self->priv->buttons[APPLY_ICC_PROFILE_BUTTON] =
 			gth_browser_add_header_bar_toggle_button (browser,
-							   	  GTH_BROWSER_HEADER_SECTION_VIEWER_TOOLS,
+							   	  GTH_BROWSER_HEADER_SECTION_VIEWER_OTHER_COMMANDS,
 								  "color-profile",
 								  _("Apply the embedded color profile"),
 								  "win.apply-icc-profile",
 								  NULL);
 
+	self->priv->buttons[TOGGLE_ANIMATION_BUTTON] =
+			gth_browser_add_header_bar_toggle_button (browser,
+							   	  GTH_BROWSER_HEADER_SECTION_VIEWER_COMMANDS,
+								  "media-playback-start-symbolic",
+								  _("Play"),
+								  "win.toggle-animation",
+								  NULL);
+	self->priv->buttons[STEP_ANIMATION_BUTTON] =
+			gth_browser_add_header_bar_button (browser,
+							   GTH_BROWSER_HEADER_SECTION_VIEWER_COMMANDS,
+							   "media-skip-forward-symbolic",
+							   _("Next frame"),
+							   "win.step-animation",
+							   NULL);
+
 	gth_window_add_accelerators (GTH_WINDOW (browser), accelerators, G_N_ELEMENTS (accelerators));
 
 	self->priv->preloader = gth_browser_get_image_preloader (browser);
 
 	self->priv->viewer = gth_image_viewer_new ();
-	g_object_add_weak_pointer (G_OBJECT (self->priv->viewer), &self->priv->viewer);
 	gtk_widget_add_events (self->priv->viewer, GDK_ENTER_NOTIFY_MASK | GDK_LEAVE_NOTIFY_MASK);
 	gth_image_viewer_page_reset_viewer_tool (self);
 	gtk_widget_show (self->priv->viewer);
@@ -1014,10 +1080,13 @@ gth_image_viewer_page_real_deactivate (GthViewerPage *base)
 	self = (GthImageViewerPage*) base;
 
 	for (i = 0; i < N_HEADER_BAR_BUTTONS; i++) {
-		gtk_widget_destroy (self->priv->buttons[i]);
-		self->priv->buttons[i] = NULL;
+		if (self->priv->buttons[i] != NULL) {
+			gtk_widget_destroy (self->priv->buttons[i]);
+			self->priv->buttons[i] = NULL;
+		}
 	}
 
+	_g_object_unref (self->priv->builder);
 	_g_object_unref (self->priv->preloader);
 	self->priv->preloader = NULL;
 	self->priv->active = FALSE;
@@ -1073,8 +1142,6 @@ preloader_load_ready_cb (GObject	*source_object,
 	GError		   *error = NULL;
 
 	self->priv->loading_image = FALSE;
-	if (! _gth_image_viewer_page_load_with_preloader_finish (self))
-		return;
 
 	if (! gth_image_preloader_load_finish (GTH_IMAGE_PRELOADER (source_object),
 					       result,
@@ -1140,6 +1207,10 @@ clear_data:
 }
 
 
+#define N_FORWARD_PRELOADERS 2
+#define N_BACKWARD_PRELOADERS 2
+
+
 static void
 _gth_image_viewer_page_load (GthImageViewerPage *self,
 		             GthFileData        *file_data)
@@ -1147,6 +1218,8 @@ _gth_image_viewer_page_load (GthImageViewerPage *self,
 	GthFileStore *file_store;
 	GtkTreeIter   iter;
 	int           i;
+	GthFileData  *next_file_data[N_FORWARD_PRELOADERS];
+	GthFileData  *prev_file_data[N_BACKWARD_PRELOADERS];
 
 	if (self->priv->file_data != file_data) {
 		_g_object_unref (self->priv->file_data);
@@ -1156,9 +1229,9 @@ _gth_image_viewer_page_load (GthImageViewerPage *self,
 	self->priv->loading_image = TRUE;
 
 	for (i = 0; i < N_FORWARD_PRELOADERS; i++)
-		_g_clear_object (&self->priv->next_file_data[i]);
+		next_file_data[i] = NULL;
 	for (i = 0; i < N_BACKWARD_PRELOADERS; i++)
-		_g_clear_object (&self->priv->prev_file_data[i]);
+		prev_file_data[i] = NULL;
 
 	file_store = gth_browser_get_file_store (self->priv->browser);
 	if (gth_file_store_find_visible (file_store, self->priv->file_data->file, &iter)) {
@@ -1168,29 +1241,36 @@ _gth_image_viewer_page_load (GthImageViewerPage *self,
 		for (i = 0; i < N_FORWARD_PRELOADERS; i++) {
 			if (! gth_file_store_get_next_visible (file_store, &next_iter))
 				break;
-			self->priv->next_file_data[i] = g_object_ref (gth_file_store_get_file (file_store, &next_iter));
+			next_file_data[i] = gth_file_store_get_file (file_store, &next_iter);
 		}
 
 		next_iter = iter;
 		for (i = 0; i < N_BACKWARD_PRELOADERS; i++) {
 			if (! gth_file_store_get_prev_visible (file_store, &next_iter))
 				break;
-			self->priv->prev_file_data[i] = g_object_ref (gth_file_store_get_file (file_store, &next_iter));
+			prev_file_data[i] = gth_file_store_get_file (file_store, &next_iter);
 		}
 
 		gth_image_viewer_set_void (GTH_IMAGE_VIEWER (self->priv->viewer));
 	}
 
-	_gth_image_viewer_page_load_with_preloader (self,
-						    self->priv->file_data,
+	_gth_image_preloader_init_preloader (self);
+	gth_image_preloader_load (self->priv->preloader,
+				  self->priv->file_data,
 #ifdef ALWAYS_LOAD_ORIGINAL_SIZE
-						    GTH_ORIGINAL_SIZE,
+				  GTH_ORIGINAL_SIZE,
 #else
-						    _gth_image_preloader_get_requested_size_for_next_images (self),
+				  _gth_image_preloader_get_requested_size_for_next_images (self),
 #endif
-						    NULL,
-						    preloader_load_ready_cb,
-						    self);
+				  NULL,
+				  preloader_load_ready_cb,
+				  self,
+				  N_FORWARD_PRELOADERS + N_BACKWARD_PRELOADERS,
+				  next_file_data[0],
+				  next_file_data[1],
+				  prev_file_data[0],
+				  prev_file_data[1]);
+
 }
 
 
@@ -1275,33 +1355,26 @@ static void
 gth_image_viewer_page_real_update_sensitivity (GthViewerPage *base)
 {
 	GthImageViewerPage *self;
-	gboolean            zoom_enabled;
-	double              zoom;
-	GthFit              fit_mode;
 	GthImage           *image;
+	gboolean            is_animation;
 
 	self = (GthImageViewerPage*) base;
 
 	gth_window_enable_action (GTH_WINDOW (self->priv->browser), "image-undo", gth_image_history_can_undo (self->priv->history));
 	gth_window_enable_action (GTH_WINDOW (self->priv->browser), "image-redo", gth_image_history_can_redo (self->priv->history));
 
-	zoom_enabled = gth_image_viewer_get_zoom_enabled (GTH_IMAGE_VIEWER (self->priv->viewer));
-	zoom = gth_image_viewer_get_zoom (GTH_IMAGE_VIEWER (self->priv->viewer));
-
-	gth_window_enable_action (GTH_WINDOW (self->priv->browser), "image-zoom-100", zoom_enabled && ! FLOAT_EQUAL (zoom, 1.0));
-	gth_window_enable_action (GTH_WINDOW (self->priv->browser), "image-zoom-out", zoom_enabled && (zoom > 0.05));
-	gth_window_enable_action (GTH_WINDOW (self->priv->browser), "image-zoom-in", zoom_enabled && (zoom < 100.0));
-
-	fit_mode = gth_image_viewer_get_fit_mode (GTH_IMAGE_VIEWER (self->priv->viewer));
-	gth_window_enable_action (GTH_WINDOW (self->priv->browser), "image-zoom-fit", zoom_enabled && (fit_mode != GTH_FIT_SIZE));
-	gth_window_enable_action (GTH_WINDOW (self->priv->browser), "image-zoom-fit-width", zoom_enabled && (fit_mode != GTH_FIT_WIDTH));
-	gth_window_enable_action (GTH_WINDOW (self->priv->browser), "image-zoom-fit-height", zoom_enabled && (fit_mode != GTH_FIT_HEIGHT));
-
 	image = gth_image_viewer_get_image (GTH_IMAGE_VIEWER (self->priv->viewer));
 	gtk_widget_set_visible (self->priv->buttons[APPLY_ICC_PROFILE_BUTTON], (image != NULL) && (gth_image_get_icc_profile (image) != NULL));
 	gth_window_enable_action (GTH_WINDOW (self->priv->browser), "apply-icc-profile", (image != NULL) && (gth_image_get_icc_profile (image) != NULL));
 
+	is_animation = gth_image_viewer_is_animation (GTH_IMAGE_VIEWER (self->priv->viewer));
+	gtk_widget_set_visible (self->priv->buttons[TOGGLE_ANIMATION_BUTTON], is_animation);
+	gtk_widget_set_visible (self->priv->buttons[STEP_ANIMATION_BUTTON], is_animation);
+	gth_window_enable_action (GTH_WINDOW (self->priv->browser), "step-animation", ! gth_image_viewer_is_playing_animation (GTH_IMAGE_VIEWER (self->priv->viewer)));
+
 	_gth_image_viewer_page_update_paste_command_sensitivity (self, NULL);
+
+	update_zoom_info (self);
 }
 
 
@@ -1517,6 +1590,7 @@ gth_image_viewer_page_real_save_as (GthViewerPage *base,
 	file_sel = gth_file_chooser_dialog_new (_("Save Image"),
 						GTK_WINDOW (self->priv->browser),
 						"image-saver");
+	_gtk_dialog_add_class_to_response (GTK_DIALOG (file_sel), GTK_RESPONSE_OK, GTK_STYLE_CLASS_SUGGESTED_ACTION);
 
 	uri = g_file_get_uri (self->priv->file_data->file);
 	gtk_file_chooser_set_uri (GTK_FILE_CHOOSER (file_sel), uri);
@@ -1652,7 +1726,6 @@ static void
 gth_image_viewer_page_finalize (GObject *obj)
 {
 	GthImageViewerPage *self;
-	int                 i;
 
 	self = GTH_IMAGE_VIEWER_PAGE (obj);
 
@@ -1674,11 +1747,6 @@ gth_image_viewer_page_finalize (GObject *obj)
 	_g_object_unref (self->priv->file_data);
 	_g_object_unref (self->priv->last_loaded);
 
-	for (i = 0; i < N_FORWARD_PRELOADERS; i++)
-		_g_clear_object (&self->priv->next_file_data[i]);
-	for (i = 0; i < N_BACKWARD_PRELOADERS; i++)
-		_g_clear_object (&self->priv->prev_file_data[i]);
-
 	G_OBJECT_CLASS (gth_image_viewer_page_parent_class)->finalize (obj);
 }
 
@@ -1734,15 +1802,11 @@ gth_image_viewer_page_init (GthImageViewerPage *self)
 	self->priv->update_visibility_id = 0;
 	for (i = 0; i < N_HEADER_BAR_BUTTONS; i++)
 		self->priv->buttons[i] = NULL;
+	self->priv->builder = NULL;
 	self->priv->pointer_on_overview = FALSE;
 	self->priv->pointer_on_viewer = FALSE;
 	self->priv->hide_overview_id = 0;
 	self->priv->apply_icc_profile = TRUE;
-
-	for (i = 0; i < N_FORWARD_PRELOADERS; i++)
-		self->priv->next_file_data[i] = NULL;
-	for (i = 0; i < N_BACKWARD_PRELOADERS; i++)
-		self->priv->prev_file_data[i] = NULL;
 }
 
 
@@ -1970,7 +2034,6 @@ get_original_data_free (OriginalImageData *data)
 	if (data == NULL)
 		return;
 
-	_g_object_unref (data->viewer_page);
 	_g_object_unref (data->cancellable);
 	_g_object_unref (data->result);
 	g_free (data);
@@ -1983,13 +2046,8 @@ original_image_ready_cb (GObject	*source_object,
 			 gpointer	 user_data)
 {
 	OriginalImageData *data = user_data;
-	GthImage          *image = NULL;
-	GError            *error = NULL;
-
-	if (! _gth_image_viewer_page_load_with_preloader_finish (data->viewer_page)) {
-		get_original_data_free (data);
-		return;
-	}
+	GthImage        *image = NULL;
+	GError          *error = NULL;
 
 	if (! gth_image_preloader_load_finish (GTH_IMAGE_PRELOADER (source_object),
 					       result,
@@ -2021,7 +2079,7 @@ gth_image_viewer_page_get_original (GthImageViewerPage	 *self,
 	OriginalImageData *data;
 
 	data = get_original_data_new ();
-	data->viewer_page = g_object_ref (self);
+	data->viewer_page = self;
 	data->result = g_simple_async_result_new (G_OBJECT (self),
 						  ready_callback,
 						  user_data,
@@ -2040,12 +2098,15 @@ gth_image_viewer_page_get_original (GthImageViewerPage	 *self,
 		get_original_data_free (data);
 	}
 	else {
-		_gth_image_viewer_page_load_with_preloader (self,
-							    self->priv->image_changed ? GTH_MODIFIED_IMAGE : self->priv->file_data,
-							    GTH_ORIGINAL_SIZE,
-							    data->cancellable,
-							    original_image_ready_cb,
-							    data);
+		_gth_image_preloader_init_preloader (self);
+		gth_image_preloader_load (self->priv->preloader,
+					  self->priv->image_changed ? GTH_MODIFIED_IMAGE : self->priv->file_data,
+					  GTH_ORIGINAL_SIZE,
+					  data->cancellable,
+					  original_image_ready_cb,
+					  data,
+					  GTH_NO_PRELOADERS,
+					  NULL);
 	}
 }
 
