@@ -169,12 +169,11 @@ list_tools__gth_browser_construct_cb (GthBrowser *browser)
 
 	/* browser tools */
 
-	button = _gtk_menu_button_new_for_header_bar ();
+	button = _gtk_menu_button_new_for_header_bar ("tools-symbolic");
 	g_signal_connect (button, "toggled", G_CALLBACK (tools_menu_button_toggled_cb), data);
 	gtk_widget_set_tooltip_text (button, _("Tools"));
-	gtk_container_add (GTK_CONTAINER (button), gtk_image_new_from_icon_name ("tools-symbolic", GTK_ICON_SIZE_MENU));
 	gtk_menu_button_set_menu_model (GTK_MENU_BUTTON (button), menu);
-	gtk_widget_show_all (button);
+	gtk_widget_show (button);
 	gtk_box_pack_start (GTK_BOX (gth_browser_get_headerbar_section (browser, GTH_BROWSER_HEADER_SECTION_BROWSER_TOOLS)), button, FALSE, FALSE, 0);
 
 	g_object_unref (builder);
