@@ -114,12 +114,7 @@ oauth_account_chooser_dialog_init (OAuthAccountChooserDialog *self)
 	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, OAUTH_TYPE_ACCOUNT_CHOOSER_DIALOG, OAuthAccountChooserDialogPrivate);
 	self->priv->builder = _gtk_builder_new_from_file ("oauth-account-chooser.ui", "oauth");
 
-	gtk_window_set_resizable (GTK_WINDOW (self), FALSE);
-	gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (self))), 5);
-	gtk_container_set_border_width (GTK_CONTAINER (self), 5);
-
 	content = _gtk_builder_get_widget (self->priv->builder, "account_chooser");
-	gtk_container_set_border_width (GTK_CONTAINER (content), 5);
 	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (self))), content, TRUE, TRUE, 0);
 
 	{
@@ -149,16 +144,12 @@ oauth_account_chooser_dialog_init (OAuthAccountChooserDialog *self)
 			  G_CALLBACK (account_combobox_changed_cb),
 			  self);
 
-	gtk_dialog_add_button (GTK_DIALOG (self),
-			       _("_New"),
-			       OAUTH_ACCOUNT_CHOOSER_RESPONSE_NEW);
-	gtk_dialog_add_button (GTK_DIALOG (self),
-			       _GTK_LABEL_CANCEL,
-			       GTK_RESPONSE_CANCEL);
-	gtk_dialog_add_button (GTK_DIALOG (self),
-			       _GTK_LABEL_OK,
-			       GTK_RESPONSE_OK);
+	gtk_dialog_add_buttons (GTK_DIALOG (self),
+				_GTK_LABEL_CANCEL, GTK_RESPONSE_CANCEL,
+				_("_Continue"), GTK_RESPONSE_OK,
+				NULL);
 	gtk_dialog_set_default_response (GTK_DIALOG (self), GTK_RESPONSE_OK);
+	_gtk_dialog_add_class_to_response (GTK_DIALOG (self), GTK_RESPONSE_OK, GTK_STYLE_CLASS_SUGGESTED_ACTION);
 }
 
 
@@ -212,7 +203,10 @@ oauth_account_chooser_dialog_new (GList        *accounts,
 {
 	OAuthAccountChooserDialog *self;
 
-	self = g_object_new (OAUTH_TYPE_ACCOUNT_CHOOSER_DIALOG, NULL);
+	self = g_object_new (OAUTH_TYPE_ACCOUNT_CHOOSER_DIALOG,
+			     "resizable", FALSE,
+			     "use-header-bar", _gtk_settings_get_dialogs_use_header (),
+			     NULL);
 	oauth_account_chooser_dialog_construct (self, accounts, default_account);
 
 	return (GtkWidget *) self;
