@@ -28,6 +28,7 @@
 #include "gth-image.h"
 #include "gth-menu-manager.h"
 #include "gth-task.h"
+#include "gth-viewer-page.h"
 #include "gth-window.h"
 #include "typedefs.h"
 
@@ -86,12 +87,15 @@ typedef enum { /*< skip >*/
 	GTH_BROWSER_HEADER_SECTION_BROWSER_TOOLS,
 	GTH_BROWSER_HEADER_SECTION_BROWSER_VIEW,
 	GTH_BROWSER_HEADER_SECTION_VIEWER_NAVIGATION,
-	GTH_BROWSER_HEADER_SECTION_VIEWER_COMMANDS,
-	GTH_BROWSER_HEADER_SECTION_VIEWER_TOOLS,
+	GTH_BROWSER_HEADER_SECTION_VIEWER_OTHER_VIEW,
 	GTH_BROWSER_HEADER_SECTION_VIEWER_VIEW,
-	GTH_BROWSER_HEADER_SECTION_VIEWER_EDIT_SIDEBAR,
+	GTH_BROWSER_HEADER_SECTION_VIEWER_ZOOM, /* section shared by viewer and editor */
+	GTH_BROWSER_HEADER_SECTION_VIEWER_COMMANDS,
+	GTH_BROWSER_HEADER_SECTION_VIEWER_OTHER_COMMANDS,
+	GTH_BROWSER_HEADER_SECTION_VIEWER_SIDEBAR,
 	GTH_BROWSER_HEADER_SECTION_VIEWER_EDIT,
 	GTH_BROWSER_HEADER_SECTION_EDITOR_NAVIGATION,
+	GTH_BROWSER_HEADER_SECTION_EDITOR_VIEW,
 	GTH_BROWSER_HEADER_SECTION_EDITOR_COMMANDS,
 	GTH_BROWSER_HEADER_SECTION_EDITOR_APPLY,
 	GTH_BROWSER_N_HEADER_SECTIONS
@@ -172,6 +176,12 @@ GtkWidget *	 gth_browser_add_header_bar_label_button
 						     const char			*tooltip,
 						     const char			*action_name,
 						     const char			*accelerator);
+GtkWidget *      gth_browser_add_header_bar_menu_button
+						    (GthBrowser			*browser,
+						     GthBrowserHeaderSection	 section,
+						     const char      	        *icon_name,
+						     const char                 *tooltip,
+						     GtkWidget                  *popover);
 void		 gth_browser_add_menu_manager_for_menu
 						    (GthBrowser			*browser,
 						     const char			*menu_id,
@@ -198,7 +208,7 @@ void             gth_browser_stop                   (GthBrowser       *browser);
 void             gth_browser_reload                 (GthBrowser       *browser);
 void             gth_browser_exec_task              (GthBrowser       *browser,
 						     GthTask          *task,
-						     gboolean          foreground);
+						     GthTaskFlags      flags);
 void             gth_browser_set_close_with_task    (GthBrowser       *browser,
 						     gboolean          value);
 gboolean         gth_browser_get_close_with_task    (GthBrowser       *browser);
@@ -213,7 +223,7 @@ gboolean         gth_browser_viewer_key_press_cb    (GthBrowser       *browser,
 void             gth_browser_set_viewer_widget      (GthBrowser       *browser,
 						     GtkWidget        *widget);
 GtkWidget *      gth_browser_get_viewer_widget      (GthBrowser       *browser);
-GtkWidget *      gth_browser_get_viewer_page        (GthBrowser       *browser);
+GthViewerPage *  gth_browser_get_viewer_page        (GthBrowser       *browser);
 GtkWidget *      gth_browser_get_viewer_sidebar     (GthBrowser       *browser);
 gboolean         gth_browser_show_next_image        (GthBrowser       *browser,
 						     gboolean          skip_broken,
@@ -263,6 +273,10 @@ void             gth_browser_save_state             (GthBrowser       *browser);
 gboolean         gth_browser_restore_state          (GthBrowser       *browser);
 void		 gth_browser_apply_editor_changes   (GthBrowser	      *browser);
 GthICCProfile    gth_browser_get_screen_profile     (GthBrowser	      *browser);
+GtkWidget *      gth_browser_get_fullscreen_headerbar
+						    (GthBrowser	      *browser);
+void             gth_browser_keep_mouse_visible     (GthBrowser	      *browser,
+						     gboolean          value);
 
 /* utilities */
 
