@@ -39,6 +39,8 @@ struct _GthFileToolPrivate {
 	const char		*options_title;
 	GthToolboxSection	 section;
 	gboolean		 cancelled;
+	gboolean                 zoomable;
+	gboolean                 changes_image;
 };
 
 
@@ -152,6 +154,8 @@ gth_file_tool_init (GthFileTool *self)
 	self->priv->icon_name = NULL;
 	self->priv->options_title = NULL;
 	self->priv->cancelled = FALSE;
+	self->priv->zoomable = FALSE;
+	self->priv->changes_image = TRUE;
 	self->priv->section = GTH_TOOLBOX_SECTION_COLORS;
 
 	/*gtk_button_set_relief (GTK_BUTTON (self), GTK_RELIEF_NONE);*/
@@ -230,6 +234,36 @@ gth_file_tool_is_cancelled (GthFileTool *self)
 }
 
 
+void
+gth_file_tool_set_zoomable (GthFileTool *self,
+			    gboolean     zoomable)
+{
+	self->priv->zoomable = zoomable;
+}
+
+
+gboolean
+gth_file_tool_get_zoomable (GthFileTool *self)
+{
+	return self->priv->zoomable;
+}
+
+
+void
+gth_file_tool_set_changes_image (GthFileTool *self,
+				 gboolean     value)
+{
+	self->priv->changes_image = value;
+}
+
+
+gboolean
+gth_file_tool_get_changes_image (GthFileTool *self)
+{
+	return self->priv->changes_image;
+}
+
+
 void
 gth_file_tool_update_sensitivity (GthFileTool *self)
 {
