@@ -29,6 +29,7 @@
 
 
 #define SIZE_TOO_BIG_FOR_SCALE_BILINEAR (3000 * 3000)
+#define MAX_ZOOM_LEVEL_FOR_HIGH_QUALITY 3.0
 #define FRAME_BORDER 15
 
 
@@ -166,9 +167,7 @@ gth_image_dragger_set_viewer (GthImageViewerTool *base,
 			      GthImageViewer     *image_viewer)
 {
 	GthImageDragger *self = GTH_IMAGE_DRAGGER (base);
-
 	self->priv->viewer = image_viewer;
-	g_object_add_weak_pointer (G_OBJECT (image_viewer), &self->priv->viewer);
 	if (self->priv->show_frame)
 		gth_image_viewer_show_frame (self->priv->viewer, FRAME_BORDER);
 }
@@ -182,7 +181,6 @@ gth_image_dragger_unset_viewer (GthImageViewerTool *base,
 
 	if ((self->priv->viewer != NULL) && self->priv->show_frame)
 		gth_image_viewer_hide_frame (self->priv->viewer);
-	g_object_remove_weak_pointer (G_OBJECT (image_viewer), &self->priv->viewer);
 	self->priv->viewer = NULL;
 }
 
@@ -269,7 +267,7 @@ gth_image_dragger_draw (GthImageViewerTool *self,
 
 	gth_image_viewer_paint_frame (viewer, cr);
 
-	if (dragger->priv->scaled != NULL)
+	if (dragger->priv->scaled != NULL) {
 		gth_image_viewer_paint_region (viewer,
 					       cr,
 					       dragger->priv->scaled,
@@ -277,14 +275,18 @@ gth_image_dragger_draw (GthImageViewerTool *self,
 					       viewer->image_area.y,
 					       &viewer->visible_area,
 					       CAIRO_FILTER_FAST);
-	else
+	}
+	else {
+		double zoom = gth_image_viewer_get_zoom (viewer);
+
 		gth_image_viewer_paint_region (viewer,
 					       cr,
 					       gth_image_viewer_get_current_image (viewer),
 					       viewer->image_area.x,
 					       viewer->image_area.y,
 					       &viewer->visible_area,
-					       CAIRO_FILTER_FAST);
+					       (gth_image_viewer_get_zoom_quality (viewer) == GTH_ZOOM_QUALITY_HIGH) && (zoom > 1.0) && (zoom <= MAX_ZOOM_LEVEL_FOR_HIGH_QUALITY) ? CAIRO_FILTER_BILINEAR : CAIRO_FILTER_FAST);
+	}
 
 	gth_image_viewer_apply_painters (viewer, cr);
 }
@@ -403,7 +405,6 @@ scale_data_free (ScaleData *scale_data)
 		return;
 	cairo_surface_destroy (scale_data->image);
 	cairo_surface_destroy (scale_data->scaled);
-	g_object_unref (scale_data->dragger);
 	g_free (scale_data);
 }
 
@@ -434,12 +435,10 @@ _gth_image_dragger_scale_after (GthAsyncTask *task,
 	if (error == NULL) {
 		GthImageDragger *dragger = scale_data->dragger;
 
-		if ((scale_data->scaled != NULL) && (dragger->priv->viewer != NULL)) {
-			_cairo_clear_surface (&dragger->priv->scaled);
-			dragger->priv->scaled = cairo_surface_reference (scale_data->scaled);
-			if (dragger->priv->viewer != NULL)
-				gtk_widget_queue_draw (GTK_WIDGET (dragger->priv->viewer));
-		}
+		_cairo_clear_surface (&dragger->priv->scaled);
+		dragger->priv->scaled = cairo_surface_reference (scale_data->scaled);
+		if (dragger->priv->viewer != NULL)
+			gtk_widget_queue_draw (GTK_WIDGET (dragger->priv->viewer));
 
 		if (GTH_TASK (task) == dragger->priv->scale_task)
 			dragger->priv->scale_task = NULL;
@@ -462,7 +461,7 @@ _gth_image_dragger_create_scaled_high_quality (GthImageDragger *self,
 		gth_task_cancel (self->priv->scale_task);
 
 	scale_data = g_new0 (ScaleData, 1);
-	scale_data->dragger = g_object_ref (self);
+	scale_data->dragger = self;
 	scale_data->image = cairo_surface_reference (image);
 	scale_data->new_width = new_width;
 	scale_data->new_height = new_height;
