@@ -250,8 +250,8 @@ _gth_image_viewer_get_zoomed_size_for_zoom (GthImageViewer *self,
 	}
 	else {
 		int frame_border = _gth_image_viewer_get_frame_border (self);
-		if (width != NULL) *width  = (int) floor ((double) self->priv->original_width * zoom_level) + (frame_border * 2);
-		if (height != NULL) *height = (int) floor ((double) self->priv->original_height * zoom_level) + (frame_border * 2);
+		if (width != NULL) *width  = (int) round ((double) self->priv->original_width * zoom_level) + (frame_border * 2);
+		if (height != NULL) *height = (int) round ((double) self->priv->original_height * zoom_level) + (frame_border * 2);
 	}
 }
 
@@ -347,18 +347,18 @@ set_zoom (GthImageViewer *self,
 		image = gth_image_viewer_get_current_image (self);
 		if (image != NULL) {
 			double quality_zoom;
-			double zoom;
+			double old_zoom_level;
 			int    x, y;
 			int    frame_border;
 			int    new_center_x, new_center_y;
 
 			quality_zoom = (double) self->priv->original_width / cairo_image_surface_get_width (image);
-			zoom = self->priv->zoom_level * quality_zoom;
-			x = (center_x + self->visible_area.x - self->image_area.x) / zoom;
-			y = (center_y + self->visible_area.y - self->image_area.y) / zoom;
+			old_zoom_level = self->priv->zoom_level * quality_zoom;
+			x = (center_x + self->visible_area.x - self->image_area.x) / old_zoom_level;
+			y = (center_y + self->visible_area.y - self->image_area.y) / old_zoom_level;
 			frame_border = _gth_image_viewer_get_frame_border (self);
-			new_center_x = x * zoom_level * quality_zoom + frame_border;
-			new_center_y = y * zoom_level * quality_zoom + frame_border;
+			new_center_x = x * zoom_level * quality_zoom + frame_border + 1;
+			new_center_y = y * zoom_level * quality_zoom + frame_border + 1;
 
 			self->visible_area.x = new_center_x - (self->visible_area.width / 2);
 			self->visible_area.y = new_center_y - (self->visible_area.height / 2);
@@ -2112,6 +2112,11 @@ gth_image_viewer_set_zoom_quality (GthImageViewer *self,
 				   GthZoomQuality  quality)
 {
 	self->priv->zoom_quality = quality;
+
+	/* to update the zoom filter */
+
+	if (self->priv->tool != NULL)
+		gth_image_viewer_tool_zoom_changed (self->priv->tool);
 }
 
 
@@ -2132,7 +2137,7 @@ gth_image_viewer_get_zoom_quality_filter (GthImageViewer *viewer)
 	else
 		filter = CAIRO_FILTER_BEST;
 
-	if (gth_image_viewer_get_zoom (viewer) >= 1.0)
+	if (viewer->priv->zoom_level >= 1.0)
 		filter = CAIRO_FILTER_FAST;
 
 	return filter;
