@@ -44,8 +44,8 @@ _gtk_message_dialog_new (GtkWindow        *parent,
 	dialog = g_object_new (GTK_TYPE_MESSAGE_DIALOG,
 			       "title", "",
 			       "transient-for", parent,
-			       "modal", (flags & GTK_DIALOG_MODAL),
-			       "destroy-with-parent", (flags & GTK_DIALOG_DESTROY_WITH_PARENT),
+			       "modal", ((flags & GTK_DIALOG_MODAL) == GTK_DIALOG_MODAL),
+			       "destroy-with-parent", ((flags & GTK_DIALOG_DESTROY_WITH_PARENT) == GTK_DIALOG_DESTROY_WITH_PARENT),
 			       "text", message,
 			       NULL);
 
@@ -261,6 +261,15 @@ _gtk_dialog_add_to_window_group (GtkDialog *dialog)
 }
 
 
+void
+_gtk_dialog_add_class_to_response (GtkDialog    *dialog,
+				   int           respose_id,
+				   const char	*class_name)
+{
+	gtk_style_context_add_class (gtk_widget_get_style_context (gtk_dialog_get_widget_for_response (dialog, respose_id)), class_name);
+}
+
+
 GdkPixbuf *
 _g_icon_get_pixbuf (GIcon        *icon,
 		    int           icon_size,
@@ -927,11 +936,18 @@ _gtk_menu_button_set_style_for_header_bar (GtkWidget *button)
 
 
 GtkWidget *
-_gtk_menu_button_new_for_header_bar (void)
+_gtk_menu_button_new_for_header_bar (const char *icon_name)
 {
 	GtkWidget *button;
 
 	button = gtk_menu_button_new ();
+	if (icon_name != NULL) {
+		GtkWidget *image;
+
+		image = gtk_image_new_from_icon_name (icon_name, GTK_ICON_SIZE_MENU);
+		gtk_widget_show (image);
+		gtk_container_add (GTK_CONTAINER (button), image);
+	}
 	_gtk_menu_button_set_style_for_header_bar (button);
 
 	return button;
@@ -1134,6 +1150,72 @@ _gtk_window_get_is_maximized (GtkWindow *window)
 }
 
 
+gboolean
+_gtk_window_get_monitor_info (GtkWindow	   *window,
+			      GdkRectangle *geometry,
+			      int          *number)
+{
+#if GTK_CHECK_VERSION(3, 22, 0)
+
+	GdkWindow  *win;
+	GdkMonitor *monitor;
+
+	win = gtk_widget_get_window (GTK_WIDGET (window));
+	if (win == NULL)
+		return FALSE;
+
+	monitor = gdk_display_get_monitor_at_window (gdk_window_get_display (win), win);
+	if (monitor == NULL)
+		return FALSE;
+
+	if (geometry != NULL)
+		gdk_monitor_get_geometry (monitor, geometry);
+
+	if (number != NULL) {
+		GdkDisplay *display;
+		int         monitor_num;
+		int         i;
+
+		display = gdk_monitor_get_display (monitor);
+		monitor_num = 0;
+		for (i = 0; /* void */; i++) {
+			GdkMonitor *m = gdk_display_get_monitor (display, i);
+			if (m == monitor) {
+				monitor_num = i;
+				break;
+			}
+			if (m == NULL)
+				break;
+		}
+		*number = monitor_num;
+	}
+
+#else
+
+	GdkWindow *win;
+	GdkScreen *screen;
+	int        monitor_num;
+
+	win = gtk_widget_get_window (GTK_WIDGET (window));
+	if (win == NULL)
+		return FALSE;
+
+	screen = gdk_window_get_screen (win);
+	if (screen == NULL)
+		return FALSE;
+
+	monitor_num = gdk_screen_get_monitor_at_window (screen, win);
+	if (number != NULL)
+		*number = monitor_num;
+
+	if (geometry != NULL)
+		gdk_screen_get_monitor_geometry (screen, monitor_num, geometry);
+#endif
+
+	return TRUE;
+}
+
+
 GdkDevice *
 _gtk_widget_get_client_pointer (GtkWidget *widget)
 {
