@@ -42,6 +42,8 @@ G_BEGIN_DECLS
 #define _GTK_LABEL_OK _("_Ok")
 #define _GTK_LABEL_REMOVE _("_Remove")
 #define _GTK_LABEL_SAVE _("_Save")
+#define _GTK_LABEL_EXECUTE _("E_xecute")
+#define _GTK_LABEL_UPLOAD _("_Upload")
 
 
 typedef struct {
@@ -61,14 +63,6 @@ GtkWidget *     _gtk_yesno_dialog_new                      (GtkWindow        *pa
 							    const char       *message,
 							    const char       *no_button_text,
 							    const char       *yes_button_text);
-gchar *		_gtk_request_dialog_run			   (GtkWindow        *parent,
-							    GtkDialogFlags    flags,
-							    const char       *title,
-							    const char       *message,
-							    const char       *default_value,
-							    int               max_length,
-							    const char       *no_button_text,
-							    const char       *yes_button_text);
 void            _gtk_error_dialog_from_gerror_run          (GtkWindow        *parent,
 					    	    	    const char       *title,
 					    	    	    GError           *gerror);
@@ -86,6 +80,9 @@ void            _gtk_info_dialog_run                       (GtkWindow        *pa
 					    	    	    const gchar      *format,
 					    	    	    ...) G_GNUC_PRINTF (2, 3);
 void            _gtk_dialog_add_to_window_group            (GtkDialog        *dialog);
+void            _gtk_dialog_add_class_to_response          (GtkDialog        *dialog,
+		   	   	   	   	   	    int               respose_id,
+							    const char	     *class_name);
 GdkPixbuf *     _g_icon_get_pixbuf                         (GIcon            *icon,
 		 			    	    	    int               icon_size,
 		 			    	    	    GtkIconTheme     *icon_theme);
@@ -142,7 +139,7 @@ void            _gtk_combo_box_add_image_sizes             (GtkComboBox      *co
 gboolean        _gtk_file_chooser_set_file_parent          (GtkFileChooser   *chooser,
 							    GFile            *file,
 							    GError          **error);
-GtkWidget *     _gtk_menu_button_new_for_header_bar        (void);
+GtkWidget *     _gtk_menu_button_new_for_header_bar        (const char       *icon_name);
 GtkWidget *     _gtk_image_button_new_for_header_bar       (const char       *icon_name);
 GtkWidget *     _gtk_toggle_image_button_new_for_header_bar(const char       *icon_name);
 void		_gtk_window_add_accelerator_for_action     (GtkWindow		*window,
@@ -153,8 +150,12 @@ void		_gtk_window_add_accelerator_for_action     (GtkWindow		*window,
 void		_gtk_window_add_accelerators_from_menu	   (GtkWindow		*window,
 							    GMenuModel		*menu);
 gboolean	_gtk_window_get_is_maximized 		   (GtkWindow		*window);
+gboolean        _gtk_window_get_monitor_info               (GtkWindow		*window,
+							    GdkRectangle        *geometry,
+							    int                 *number);
 GdkDevice *     _gtk_widget_get_client_pointer		   (GtkWidget		*widget);
 void            _gtk_list_box_add_separator		   (GtkListBox		*list_box);
+gboolean        _gtk_settings_get_dialogs_use_header       (void);
 
 G_END_DECLS
 
